## Single files

Package `datamaestro.download.single`

@@api:datamaestro.download.single.filedownloader

@@api:datamaestro.download.single.concatdownload


## Archives

Package `datamaestro.download.archive`

@@api:datamaestro.download.archive.zipdownloader
@@api:datamaestro.download.archive.tardownloader


## Links

Package `datamaestro.download.links`

@@api:datamaestro.download.links.links
@@api:datamaestro.download.links.linkfolder
@@api:datamaestro.download.links.linkfile


## Syncing

Package `datamaestro.download.sync`

@@api:datamaestro.download.sync.gsync
